Package: webutils
Type: Package
Title: Utility Functions for Developing Web Applications
Version: 1.2.2
Authors@R: person("Jeroen", "Ooms", role = c("aut", "cre"), email = "jeroenooms@gmail.com",
      comment = c(ORCID = "0000-0002-4035-0289"))
Description: Parses http request data in application/json, multipart/form-data, 
    or application/x-www-form-urlencoded format. Includes example of hosting
    and parsing html form data in R using either 'httpuv' or 'Rhttpd'.
License: MIT + file LICENSE
URL: https://jeroen.r-universe.dev/webutils
BugReports: https://github.com/jeroen/webutils/issues
Imports: curl (>= 2.5), jsonlite
Suggests: httpuv, testthat
RoxygenNote: 7.3.2.9000
Language: en-US
Encoding: UTF-8
NeedsCompilation: yes
Packaged: 2024-10-03 14:13:23 UTC; jeroen
Author: Jeroen Ooms [aut, cre] (<https://orcid.org/0000-0002-4035-0289>)
Maintainer: Jeroen Ooms <jeroenooms@gmail.com>
Repository: CRAN
Date/Publication: 2024-10-04 09:00:05 UTC
Built: R 4.6.0; x86_64-apple-darwin20; 2026-04-26 10:38:52 UTC; unix
Archs: webutils.so.dSYM
