Package: webutils
Type: Package
Title: Utility Functions for Developing Web Applications
Version: 1.2.3
Authors@R: person("Jeroen", "Ooms", role = c("aut", "cre"), email = "jeroenooms@gmail.com",
      comment = c(ORCID = "0000-0002-4035-0289"))
Description: Parses http request data in application/json, multipart/form-data, 
    or application/x-www-form-urlencoded format. Includes example of hosting
    and parsing html form data in R using either 'httpuv' or 'Rhttpd'.
License: MIT + file LICENSE
URL: https://jeroen.r-universe.dev/webutils
BugReports: https://github.com/jeroen/webutils/issues
Imports: curl (>= 2.5), jsonlite
Suggests: httpuv, testthat
RoxygenNote: 7.3.2.9000
Language: en-US
Encoding: UTF-8
NeedsCompilation: yes
Packaged: 2026-07-20 14:41:50 UTC; jeroen
Author: Jeroen Ooms [aut, cre] (ORCID: <https://orcid.org/0000-0002-4035-0289>)
Maintainer: Jeroen Ooms <jeroenooms@gmail.com>
Repository: CRAN
Date/Publication: 2026-07-20 19:50:02 UTC
