A string of different Python modules or utilities that I find useful. 
This has been a private repo for years that I've used in several projects 
and slowly molded into amore useful set of modules.

I either create, adapted from existing snippet/code, or just included 
these files all together.

Credit is always given to the original author. If you find something 
that isn't, please notify me immediately and I'll give proper credit.

NOTE:

Some of this code is old, outdated, not used anymore at all and I 
just forgot to remove it from the repository. That old and unmaintained 
code will eventually be removed from this repository. Warning: That 
code may be ugly! Don't hang me for it ;)


Use
---

Basic Install:

  $ python setup.py build
  $ sudo python setup.py install

Alternative Install (Manually):

Place webutils directory in your Python path. Either in your Python 
installs site-packages directory or set your $PYTHONPATH environment 
variable to include a directory where the webutils directory lives.


Copyright & Warranty
--------------------
All documentation, libraries, and sample code are 
Copyright 2010 Peter Sanchez <petersanchez@gmail.com>. The library and 
sample code are made available to you under the terms of the BSD license 
which is contained in the included file, BSD-LICENSE.
